@@ -31,7 +31,7 @@ class CDasherButtons : public CInputFilter
   bool DecorateView(CDasherView *pView);
   
   void KeyDown(int iTime, int iId, CDasherModel *pModel);
-  void Timer(int Time, CDasherView *m_pDasherView, CDasherModel *m_pDasherModel);
+  bool Timer(int Time, CDasherView *m_pDasherView, CDasherModel *m_pDasherModel);
 
   void SetupBoxes();
 
@@ -41,6 +41,8 @@ class CDasherButtons : public CInputFilter
     int iDisplayTop;
     int iDisplayBottom;
   };
+
+  bool GetSettings(SModuleSettings **pSettings, int *iCount);
     
  private:
   CSettingsStore*  m_pSettingsStore;
@@ -59,6 +61,7 @@ class CDasherButtons : public CInputFilter
 
   int m_iLastTime;
   bool m_bHighlight;
+  bool m_bDecorationChanged;
 
 };
 
