@@ -15,6 +15,7 @@
 
 #include "../DasherInterface.h"
 #include "../../DasherCore/ColourIO.h"
+#include "../ModuleSettings.h"
 
 class CAppSettings;
 
@@ -30,12 +31,17 @@ private:
   std::string m_CurrentColours;
   Dasher::CColourIO::ColourInfo CurrentInfo;
   TCHAR m_tcBuffer[1000];
+  
+  // Handles to important widgets
   HWND SB_slider;
   HWND speedbox;
-  // Some status flags:
+  HWND m_hMousePosStyle;
+  
   void PopulateList();
   bool Apply();
   bool Validate();
+
+  CModuleSettings *m_pModuleSettingsDialogue;
 };
 
 #endif  // ndef
